summaryrefslogtreecommitdiff
path: root/NxWidgets/libnxwidgets/include/inxwindow.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'NxWidgets/libnxwidgets/include/inxwindow.hxx')
-rw-r--r--NxWidgets/libnxwidgets/include/inxwindow.hxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/NxWidgets/libnxwidgets/include/inxwindow.hxx b/NxWidgets/libnxwidgets/include/inxwindow.hxx
index 4aa2c519b..3e2f6c4a1 100644
--- a/NxWidgets/libnxwidgets/include/inxwindow.hxx
+++ b/NxWidgets/libnxwidgets/include/inxwindow.hxx
@@ -48,7 +48,7 @@
#include <stdbool.h>
#ifdef CONFIG_NXTERM_NXKBDIN
-# include <nuttx/nx/nxconsole.h>
+# include <nuttx/nx/nxterm.h>
#endif
/****************************************************************************
@@ -175,19 +175,19 @@ namespace NXWidgets
/**
* Each window implementation also inherits from CCallback. CCallback,
* by default, forwards NX keyboard input to the various widgets residing
* in the window. But NxConsole is a different usage model; In this case,
* keyboard input needs to be directed to the NxConsole character driver.
* This method can be used to enable (or disable) redirection of NX
* keyboard input from the window widgets to the NxConsole
*
* @param handle. The NXCONSOLE handle. If non-NULL, NX keyboard
* input will be directed to the NxConsole driver using this
* handle; If NULL (the default), NX keyboard input will be
* directed to the widgets within the window.
*/
#ifdef CONFIG_NXTERM_NXKBDIN
- virtual void redirectNxConsole(NXCONSOLE handle) = 0;
+ virtual void redirectNxTerm(NXTERM handle) = 0;
#endif
/**
@@ -175,19 +175,19 @@ namespace NXWidgets
* Each window implementation also inherits from CCallback. CCallback,
* by default, forwards NX keyboard input to the various widgets residing
- * in the window. But NxConsole is a different usage model; In this case,
- * keyboard input needs to be directed to the NxConsole character driver.
+ * in the window. But NxTerm is a different usage model; In this case,
+ * keyboard input needs to be directed to the NxTerm character driver.
* This method can be used to enable (or disable) redirection of NX
@@ -175,19 +175,19 @@ namespace NXWidgets
* This method can be used to enable (or disable) redirection of NX
- * keyboard input from the window widgets to the NxConsole
+ * keyboard input from the window widgets to the NxTerm
*
@@ -175,19 +175,19 @@ namespace NXWidgets
*
- * @param handle. The NXCONSOLE handle. If non-NULL, NX keyboard
- * input will be directed to the NxConsole driver using this
+ * @param handle. The NXTERM handle. If non-NULL, NX keyboard
+ * input will be directed to the NxTerm driver using this
* handle; If NULL (the default), NX keyboard input will be
* directed to the widgets within the window.